==> vtk6-6.3.0-4-armv7h.pkg.tar.xz: vtk/vtkCommand.java <==
// java wrapper for vtkCommand object
//

package vtk;
import vtk.*;

public class vtkCommand extends vtkObjectBase
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void UnRegister_2();
  public void UnRegister()
    { UnRegister_2(); }

  private native void UnRegister_3(vtkObjectBase id0);
  public void UnRegister(vtkObjectBase id0)
    { UnRegister_3(id0); }

  private native String GetStringFromEventId_4(int id0);
  public String GetStringFromEventId(int id0)
    { return GetStringFromEventId_4(id0); }

  private native int GetEventIdFromString_5(String id0);
  public int GetEventIdFromString(String id0)
    { return GetEventIdFromString_5(id0); }

  private native void SetAbortFlag_6(int id0);
  public void SetAbortFlag(int id0)
    { SetAbortFlag_6(id0); }

  private native int GetAbortFlag_7();
  public int GetAbortFlag()
    { return GetAbortFlag_7(); }

  private native void AbortFlagOn_8();
  public void AbortFlagOn()
    { AbortFlagOn_8(); }

  private native void AbortFlagOff_9();
  public void AbortFlagOff()
    { AbortFlagOff_9(); }

  private native void SetPassiveObserver_10(int id0);
  public void SetPassiveObserver(int id0)
    { SetPassiveObserver_10(id0); }

  private native int GetPassiveObserver_11();
  public int GetPassiveObserver()
    { return GetPassiveObserver_11(); }

  private native void PassiveObserverOn_12();
  public void PassiveObserverOn()
    { PassiveObserverOn_12(); }

  private native void PassiveObserverOff_13();
  public void PassiveObserverOff()
    { PassiveObserverOff_13(); }

  public vtkCommand() { super(); }

  public vtkCommand(long id) { super(id); }

}

==> vtk-8.0.1-3-armv7h.pkg.tar.xz: vtk/vtkCommand.java <==
// java wrapper for vtkCommand object
//

package vtk;
import vtk.*;

public class vtkCommand extends vtkObjectBase
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void UnRegister_2();
  public void UnRegister()
    { UnRegister_2(); }

  private native void UnRegister_3(vtkObjectBase id0);
  public void UnRegister(vtkObjectBase id0)
    { UnRegister_3(id0); }

  private native String GetStringFromEventId_4(int id0);
  public String GetStringFromEventId(int id0)
    { return GetStringFromEventId_4(id0); }

  private native int GetEventIdFromString_5(String id0);
  public int GetEventIdFromString(String id0)
    { return GetEventIdFromString_5(id0); }

  private native void SetAbortFlag_6(int id0);
  public void SetAbortFlag(int id0)
    { SetAbortFlag_6(id0); }

  private native int GetAbortFlag_7();
  public int GetAbortFlag()
    { return GetAbortFlag_7(); }

  private native void AbortFlagOn_8();
  public void AbortFlagOn()
    { AbortFlagOn_8(); }

  private native void AbortFlagOff_9();
  public void AbortFlagOff()
    { AbortFlagOff_9(); }

  private native void SetPassiveObserver_10(int id0);
  public void SetPassiveObserver(int id0)
    { SetPassiveObserver_10(id0); }

  private native int GetPassiveObserver_11();
  public int GetPassiveObserver()
    { return GetPassiveObserver_11(); }

  private native void PassiveObserverOn_12();
  public void PassiveObserverOn()
    { PassiveObserverOn_12(); }

  private native void PassiveObserverOff_13();
  public void PassiveObserverOff()
    { PassiveObserverOff_13(); }

  public vtkCommand() { super(); }

  public vtkCommand(long id) { super(id); }

}
